@@ -3,13 +3,11 @@ package Test::Lazy::Template;
 use strict;
 use warnings;
 
-use base qw/Class::Accessor::Fast/;
+use base qw/Class::Accessor Exporter/;
+__PACKAGE__->mk_accessors(qw/_template/);
 
-__PACKAGE__->mk_accessors(qw/tester template/);
-
-use Test::Lazy::Tester;
+use Test::Lazy qw/try/;
 use Test::Builder();
-use Scalar::Util qw/blessed/;
 use Carp;
 
 =head1 NAME
@@ -85,7 +83,6 @@ Returns the new C<Test::Lazy::Template> object
 
 sub new {
 	my $self = bless {}, shift;
-    my $tester = blessed $_[0] && $_[0]->isa("Test::Lazy::Tester") ? shift : Test::Lazy::Tester->new;
 	my $template = $_[0];
 	if (ref $template eq 'SCALAR') {
 		my @template = map { [ $_ ] } grep { length $_ && $_ !~ m/^\s*#/ } split m/\n/, $$template;
@@ -96,8 +93,7 @@ sub new {
 	else {
 		$template = [ @_ ];
 	}
-	$self->tester($tester);
-	$self->template($template);
+	$self->_template($template);
 	return $self;
 }
 
@@ -114,17 +110,12 @@ Modify and then run each test in $template by using <test> to complete each test
 sub test {
 	my $self = shift;
 
-	my $template = $self->template;
+	my $template = $self->_template;
 	my $size = @$template;
 	my $mdf_template;
-	my $base_stmt;
 	if (ref $_[0] eq 'ARRAY') {
 		$mdf_template = shift;
 	}
-	elsif (ref $_[1] eq 'ARRAY') {
-		$base_stmt = shift;
-		$mdf_template = shift;
-	}
 	else {
 		my ($mdf_stmt, $mdf_cmpr, $mdf_rslt);
 		if (2 == @_) {
@@ -143,7 +134,7 @@ sub test {
 		
 		my ($mdf_stmt, $mdf_cmpr, $mdf_rslt);
 		if (2 == @$mdf_line) {
-			($mdf_stmt, $mdf_cmpr, $mdf_rslt) = ($base_stmt, @$mdf_line);
+			($mdf_stmt, $mdf_cmpr, $mdf_rslt) = (undef, @$mdf_line);
 		}
 		else {
 			($mdf_stmt, $mdf_cmpr, $mdf_rslt) = @$mdf_line;
@@ -161,9 +152,9 @@ sub test {
 		my ($rslt) = grep { defined } ($mdf_rslt, $line->[2]);
 
 		{
-			local $Test::Builder::Level = $Test::Builder::Level + 1;
+			local $Test::Builder::Level = $Test::Builder::Level ? $Test::Builder::Level + 2 : 2;
 
-			$self->tester->try($stmt, $cmpr, $rslt, "$index: %");
+			try($stmt, $cmpr, $rslt, "$index: %");
 		}
 	}
 
